@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.010_01';
+our $VERSION = '0.012_01';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -184,7 +184,7 @@ sub dist_dir {
       : $class->config('working_directory');
 
   croak "Failed to find share dir for dist '$dist'"
-    unless -d $dist_dir;
+    unless defined $dist_dir && -d $dist_dir;
 
   return $dist_dir;
 }
@@ -287,6 +287,16 @@ sub _keyword {
     ) }
     @pc;
 
+  if(defined $self->config('original_prefix') && $self->config('original_prefix') ne $self->dist_dir)
+  {
+    my $old = quotemeta $self->config('original_prefix');
+    @strings = map {
+      s{^(-I|-L|-LIBPATH:)?($old)}{$1.$self->dist_dir}e;
+      s/(\s)/\\$1/g;
+      $_;
+    } map { $self->split_flags($_) } @strings;
+  }
+
   return join( ' ', @strings );
 }
 
@@ -440,6 +450,7 @@ get installed into non-standard locations.
 
 sub bin_dir {
   my ($class) = @_;
+  return unless $class->install_type('share');
   my $dir = File::Spec->catfile($class->dist_dir, 'bin');
   -d $dir ? ($dir) : ();
 }
